summaryrefslogtreecommitdiffstats
path: root/src/Runtime/Source/datamodel/Qt3DSMetadata.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/Runtime/Source/datamodel/Qt3DSMetadata.h')
-rw-r--r--src/Runtime/Source/datamodel/Qt3DSMetadata.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/Runtime/Source/datamodel/Qt3DSMetadata.h b/src/Runtime/Source/datamodel/Qt3DSMetadata.h
index ea2d4452..1efe748c 100644
--- a/src/Runtime/Source/datamodel/Qt3DSMetadata.h
+++ b/src/Runtime/Source/datamodel/Qt3DSMetadata.h
@@ -32,6 +32,7 @@
#include "foundation/Qt3DSRefCounted.h"
#include "foundation/Qt3DSOption.h"
+#include "foundation/Qt3DSVec2.h"
#include "foundation/Qt3DSVec3.h"
#include "foundation/Qt3DSVec4.h"
#include <EASTL/string.h>
@@ -71,6 +72,7 @@ enum ERuntimeDataModelDataType {
ERuntimeDataModelDataTypeFloat,
ERuntimeDataModelDataTypeFloat2,
ERuntimeDataModelDataTypeFloat3,
+ ERuntimeDataModelDataTypeFloat4,
ERuntimeDataModelDataTypeLong,
ERuntimeDataModelDataTypeString,
ERuntimeDataModelDataTypeBool,
@@ -205,14 +207,14 @@ public:
//==============================================================================
/**
* Get property value as QT3DSVec3
* @param inType default object type
* @param inProperty the property to query
* @param inId object id. if this value is not trivial, the query is based on inId
*instead of inType
* @param return property value
*/
- virtual Option<qt3ds::QT3DSVec3> GetPropertyValueVector2(TStrTableStr inType, TStrTableStr inProperty,
+ virtual Option<qt3ds::QT3DSVec2> GetPropertyValueVector2(TStrTableStr inType, TStrTableStr inProperty,
TStrTableStr inId = TStrTableStr()) = 0;
//==============================================================================
@@ -205,14 +207,14 @@ public:
//==============================================================================
/**
- * Get property value as QT3DSVec3
+ * Get property value as QT3DSVec2
* @param inType default object type
* @param inProperty the property to query